@@ -1,7 +1,3 @@
-from django.core.exceptions import PermissionDenied
-from django.db.models import Q
-from django.utils.timezone import now
-
 from rest_framework import permissions
 
 from ..cms.models import GroupAPIKey
@@ -9,13 +5,15 @@ from .utils import get_key
 
 
 class VerifyGroupKey(permissions.AllowAny):
-    """Simple permissions class that blocks
+    """
+    Simple permissions class that blocks
     requests if no valid API-Token is delivered.
     Inherits from `permissions.AllowAny`.
     """
 
     def has_permission(self, request, view):
-        """Checks whether a valid API-Key is send
+        """
+        Checks whether a valid API-Key is send
         by the user in the authorization header
 
         :param request: http request
