@@ -42,7 +42,7 @@ class DisciplineSerializer(FallbackIconSerializer):
 
 
         :param disc: Discipline instance
-        :type disc: models.Discipline
+        :type disc: ~lunes_cms.cms.models.discipline.Discipline
         :return: sum of children
         :rtype: int
         """
