@@ -14,6 +14,8 @@ class DocumentSerializer(serializers.ModelSerializer):
     alternatives = AlternativeWordSerializer(many=True, read_only=True)
     document_image = DocumentImageSerializer(many=True, read_only=True)
 
+    article = serializers.IntegerField(source="singular_article")
+
     class Meta:
         """
         Define model and the corresponding fields
@@ -28,4 +30,5 @@ class DocumentSerializer(serializers.ModelSerializer):
             "word_type",
             "alternatives",
             "document_image",
+            "example_sentence",
         )
