@@ -1,6 +1,7 @@
-from rest_framework import serializers
 from django.contrib.contenttypes.models import ContentType
-from django.utils.translation import ugettext_lazy as _
+from django.core.exceptions import ObjectDoesNotExist
+from django.utils.translation import gettext_lazy as _
+from rest_framework import serializers
 
 from ....cms.models import Feedback
 
@@ -18,7 +19,8 @@ class FeedbackSerializer(serializers.ModelSerializer):
         ),
         error_messages={
             "does_not_exist": _(
-                "The content type must be either 'discipline', 'training set' or 'document'."
+                "The content type must be either 'discipline', 'training set' or"
+                " 'document'."
             ),
         },
     )
@@ -26,7 +28,8 @@ class FeedbackSerializer(serializers.ModelSerializer):
     def validate(self, attrs):
         try:
             attrs["content_type"].model_class().objects.get(pk=attrs["object_id"])
-        except:
+        except ObjectDoesNotExist as e:
+            print(e)
             raise serializers.ValidationError(
                 {
                     "object_id": [
@@ -35,7 +38,7 @@ class FeedbackSerializer(serializers.ModelSerializer):
                         ),
                     ]
                 }
-            )
+            ) from e
         return attrs
 
     class Meta:
