@@ -1,17 +1,12 @@
 """
 URL patterns for the first version of the Lunes API
 """
-from django.urls import include, path, re_path
-
-from rest_framework import permissions
-from rest_framework.versioning import NamespaceVersioning
-
+from django.urls import include, path
 from drf_spectacular.views import SpectacularAPIView, SpectacularSwaggerView
 
-from ..utils import OptionalSlashRouter
+from ..utils import OptionalSlashRouter, find_duplicates_for_word
 from . import views
 
-
 #: The namespace for this URL config (see :attr:`django.urls.ResolverMatch.app_name`)
 app_name = "v1"
 
@@ -19,7 +14,7 @@ app_name = "v1"
 router = OptionalSlashRouter()
 router.register(r"disciplines", views.DisciplineViewSet, "disciplines")
 router.register(
-    "disciplines_by_level/",
+    "disciplines_by_level",
     views.DisciplineFilteredViewSet,
     "disciplines_overview",
 )
@@ -46,7 +41,9 @@ router.register(
 )
 
 router.register(
-    r"document_by_id/(?P<document_id>[0-9]+)", views.DocumentByIdViewSet, "documents"
+    r"document_by_id/(?P<document_id>[0-9]+)",
+    views.DocumentByIdViewSet,
+    "document_by_id",
 )
 router.register(r"words", views.WordViewSet, "words")
 router.register(r"group_info", views.GroupViewSet, "group_by_id")
@@ -64,4 +61,9 @@ urlpatterns = [
         ),
         name="swagger-ui",
     ),
+    path(
+        "search_duplicate/<word>",
+        find_duplicates_for_word,
+        name="search_duplicate",
+    ),
 ]
