@@ -5,15 +5,17 @@ specify autocomplete_fields, search_fields and nested modules
 from __future__ import absolute_import, unicode_literals
 
 from django.contrib import admin
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
-from .models import Discipline, TrainingSet, Document, GroupAPIKey, Feedback, Sponsor
-from .admins import DisciplineAdmin
-from .admins import TrainingSetAdmin
-from .admins import DocumentAdmin
-from .admins import GroupAPIKeyAdmin
-from .admins import FeedbackAdmin
-from .admins import SponsorAdmin
+from .admins import (
+    DisciplineAdmin,
+    DocumentAdmin,
+    FeedbackAdmin,
+    GroupAPIKeyAdmin,
+    SponsorAdmin,
+    TrainingSetAdmin,
+)
+from .models import Discipline, Document, Feedback, GroupAPIKey, Sponsor, TrainingSet
 
 
 def get_app_list(self, request):
@@ -36,6 +38,8 @@ def get_app_list(self, request):
         _("api keys").capitalize(): 4,
         _("feedback").capitalize(): 5,
     }
+
+    # pylint: disable=protected-access
     app_dict = self._build_app_dict(request)
 
     # Sort the apps alphabetically.
@@ -51,30 +55,8 @@ def get_app_list(self, request):
 
 
 admin.AdminSite.get_app_list = get_app_list
-admin.site.register(
-    Discipline,
-    DisciplineAdmin,
-    list_display=(
-        "tree_actions",
-        "indented_title",
-        "released",
-        "creator_group",
-    ),
-    list_display_links=("indented_title",),
-)
-admin.site.register(
-    TrainingSet,
-    TrainingSetAdmin,
-    list_display=(
-        "tree_actions",
-        "indented_title",
-        "title",
-        "released",
-        "related_disciplines",
-        "creator_group",
-    ),
-    list_display_links=("indented_title",),
-)
+admin.site.register(Discipline, DisciplineAdmin)
+admin.site.register(TrainingSet, TrainingSetAdmin)
 admin.site.register(Document, DocumentAdmin)
 admin.site.register(GroupAPIKey, GroupAPIKeyAdmin)
 admin.site.register(Feedback, FeedbackAdmin)
