@@ -1,6 +1,5 @@
 from django.contrib import admin
-
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 from ..utils import get_image_tag
 
@@ -12,6 +11,7 @@ class SponsorAdmin(admin.ModelAdmin):
 
     fields = [
         "name",
+        "url",
         "logo",
         "image_tag",
     ]
@@ -47,4 +47,8 @@ class SponsorAdmin(admin.ModelAdmin):
     image_tag.short_description = ""
 
     class Media:
+        """
+        Media class of Sponsor Admin
+        """
+
         js = ("js/image_preview.js",)
