@@ -3,13 +3,15 @@ from __future__ import absolute_import, unicode_literals
 from django.conf import settings
 from django.contrib import admin, messages
 from django.db.models import Count, F, Q
-from django.utils.translation import ugettext_lazy as _, ngettext
-
+from django.urls import reverse
+from django.utils.safestring import mark_safe
+from django.utils.translation import ngettext
+from django.utils.translation import gettext_lazy as _
 from mptt.admin import DraggableMPTTAdmin
 
-from ..list_filter import DisciplineListFilter
 from ..forms import TrainingSetForm
-from ..models import Static, Document, Discipline
+from ..list_filter import DisciplineListFilter
+from ..models import Discipline, Document, Static
 from ..utils import iter_to_string
 
 
@@ -33,10 +35,32 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
     readonly_fields = ["created_by", "image_tag"]
     search_fields = ["title"]
     form = TrainingSetForm
-    list_filter = (DisciplineListFilter,)
+    list_display = [
+        "tree_actions",
+        "title",
+        "released",
+        "words",
+        "words_released",
+        "words_unreleased",
+        "related_disciplines",
+        "creator_group",
+    ]
+    list_display_links = ["title"]
+    list_filter = [DisciplineListFilter, "released"]
     actions = ["make_released", "make_unreleased"]
     list_per_page = 25
 
+    def get_list_display(self, request):
+        if request.user.is_superuser:
+            return [
+                display for display in self.list_display if display not in ["words"]
+            ]
+        return [
+            display
+            for display in self.list_display
+            if display not in ["words_released", "words_unreleased"]
+        ]
+
     def save_model(self, request, obj, form, change):
         """
         Overwrite django built-in function to save
@@ -45,7 +69,7 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
         :param request: current user request
         :type request: django.http.request
         :param obj: training set object
-        :type obj: models.TrainingSet
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
         :param form: employed model form
         :type form: ModelForm
         :param change: True if change on existing model
@@ -60,7 +84,7 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
             obj.creator_is_admin = request.user.is_superuser
         obj.save()
 
-    def get_action_choices(self, request):
+    def get_action_choices(self, request, default_choices=""):
         """
         Overwrite django built-in function to modify action choices. The first
         option is dropped since it is a place holder.
@@ -70,7 +94,7 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
         :return: modified action choices
         :rtype: dict
         """
-        choices = super(TrainingSetAdmin, self).get_action_choices(request)
+        choices = super().get_action_choices(request)
         choices.pop(0)
         return choices
 
@@ -84,12 +108,36 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
         :return: adjusted queryset
         :rtype: QuerySet
         """
-        qs = super(TrainingSetAdmin, self).get_queryset(request)
+        qs = super().get_queryset(request)
         if request.user.is_superuser:
-            return qs.filter(creator_is_admin=True)
-        return qs.filter(created_by__in=request.user.groups.all())
+            return qs.filter(creator_is_admin=True).annotate(
+                words_released=Count(
+                    "documents",
+                    filter=Q(
+                        documents__creator_is_admin=True,
+                        documents__document_image__confirmed=True,
+                    ),
+                    distinct=True,
+                ),
+                words_unreleased=Count(
+                    "documents",
+                    filter=(
+                        Q(documents__creator_is_admin=True)
+                        & ~Q(documents__document_image__confirmed=True)
+                    ),
+                    distinct=True,
+                ),
+            )
+        user_groups = request.user.groups.all()
+        return qs.filter(created_by__in=user_groups).annotate(
+            words=Count(
+                "documents",
+                filter=Q(documents__created_by__in=user_groups),
+                distinct=True,
+            ),
+        )
 
-    def get_form(self, request, obj=None, **kwargs):
+    def get_form(self, request, obj=None, change=False, **kwargs):
         """
         Overwrite django built-in function to define custom choices
         in many to many selectors, e.g. users should not see documents
@@ -103,7 +151,7 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
         :return: model form with adjusted querysets
         :rtype: ModelForm
         """
-        form = super(TrainingSetAdmin, self).get_form(request, obj, **kwargs)
+        form = super().get_form(request, obj, **kwargs)
         if not request.user.is_superuser:
             form.base_fields["discipline"].queryset = (
                 Discipline.objects.filter(
@@ -169,8 +217,10 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
             messages.error(
                 request,
                 ngettext(
-                    "The training set {} could not be released because it contains less than {} vocabulary words with confirmed images.",
-                    "The training sets {} could not be released because they contain less than {} vocabulary words with confirmed images.",
+                    "The training set {} could not be released because it contains less"
+                    " than {} vocabulary words with confirmed images.",
+                    "The training sets {} could not be released because they contain"
+                    " less than {} vocabulary words with confirmed images.",
                     len(invalid_trainingsets),
                 ).format(
                     iter_to_string(invalid_trainingsets),
@@ -243,12 +293,66 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
                 ).format(iter_to_string(released_trainingsets)),
             )
 
+    @admin.display(
+        description=_("words"),
+        ordering="-words",
+    )
+    def words(self, obj):
+        """
+        returns HTML tag of the link to the list of words related to the training set
+
+        :param obj: Training set object
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
+        :return: HTML tag of the link to the list of words related to the training set
+        :rtype: str
+        """
+        document_list = reverse("admin:cms_document_changelist")
+        return mark_safe(
+            f"<a href={document_list}?training+set={obj.id}>{obj.words}</a>"
+        )
+
+    @admin.display(
+        description=_("published words"),
+        ordering="-words_released",
+    )
+    def words_released(self, obj):
+        """
+        returns HTML tag of the link to the list of released words related to the training set
+
+        :param obj: Training set object
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
+        :return: HTML tag of the link to the list of released words related to the training set
+        :rtype: str
+        """
+        document_list = reverse("admin:cms_document_changelist")
+        return mark_safe(
+            f"<a href={document_list}?training+set={obj.id}&images=approved>{obj.words_released}</a>"
+        )
+
+    @admin.display(
+        description=_("unpublished words"),
+        ordering="-words_unreleased",
+    )
+    def words_unreleased(self, obj):
+        """
+        returns HTML tag of the Link to the list of unreleased words related to the training set
+
+        :param obj: Training set object
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
+        :return: HTML tag of the Link to the list of unreleased words related to the training set
+        :rtype: str
+        """
+        document_list = reverse("admin:cms_document_changelist")
+        return mark_safe(
+            f"<a href={document_list}?training+set={obj.id}&images=no-approved>{obj.words_unreleased}</a>"
+        )
+
     def related_disciplines(self, obj):
         """
         Display related disciplines in list display
 
         :param obj: Training set object
-        :type obj: models.TrainingSet
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
         :return: comma separated list of related disciplines
         :rtype: str
         """
@@ -261,18 +365,21 @@ class TrainingSetAdmin(DraggableMPTTAdmin):
         Include creator group of discipline in list display
 
         :param obj: Training set object
-        :type obj: models.TrainingSet
+        :type obj: ~lunes_cms.cms.models.training_set.TrainingSet
         :return: Either static admin group or user group
         :rtype: str
         """
         if obj.creator_is_admin:
             return Static.admin_group
-        elif obj.created_by:
+        if obj.created_by:
             return obj.created_by
-        else:
-            return None
+        return None
 
     creator_group.short_description = _("creator group")
 
     class Media:
+        """
+        Media class of Training Set Admin
+        """
+
         js = ("js/image_preview.js",)
