@@ -1,5 +1,5 @@
 from django.apps import AppConfig
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
 
 class CmsConfig(AppConfig):
@@ -9,4 +9,4 @@ class CmsConfig(AppConfig):
     """
 
     name = "lunes_cms.cms"
-    verbose_name = _("vocabulary management")
+    verbose_name = _("Vocabulary Management")
