@@ -1,8 +1,8 @@
 from django.db import models
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 
-from .static import upload_sponsor_logos
 from ..validators import validate_multiple_extensions
+from .static import upload_sponsor_logos
 
 
 class Sponsor(models.Model):
@@ -15,7 +15,10 @@ class Sponsor(models.Model):
         max_length=255,
         blank=False,
     )
-
+    url = models.URLField(
+        blank=True,
+        verbose_name=_("URL"),
+    )
     logo = models.ImageField(
         upload_to=upload_sponsor_logos,
         validators=[validate_multiple_extensions],
@@ -30,7 +33,7 @@ class Sponsor(models.Model):
         :return: name of the sponsor
         :rtype: str
         """
-        return self.name
+        return str(self.name)
 
     class Meta:
         """
