@@ -6,18 +6,10 @@ handles the url patterns described in the `README.md` file
 
 from django.contrib import admin
 from django.contrib.auth import views as auth_views
-from django.urls import path, include
-from django.conf.urls.static import static
-from django.conf import settings
-from django.conf.urls.i18n import i18n_patterns
-from django.conf.urls import url
-from django.templatetags.static import static as get_static_url
-from django.urls import path, reverse_lazy
-from django.utils.translation import ugettext_lazy as _
-from django.views.generic.base import RedirectView
+from django.urls import path
+from django.utils.translation import gettext_lazy as _
 from django.views.i18n import JavaScriptCatalog
 
-
 #: The url patterns of this module (see :doc:`django:topics/http/urls`)
 urlpatterns = [
     path(
