@@ -1,7 +1,8 @@
-from django.utils.translation import ugettext_lazy as _
-from django.core.exceptions import ValidationError
 import os
 
+from django.core.exceptions import ValidationError
+from django.utils.translation import gettext_lazy as _
+
 
 def validate_file_extension(value):
     """
