@@ -19,19 +19,12 @@ Including another URLconf
     2. Add a URL to urlpatterns:  path('blog/', include('blog.urls'))
 
 """
-from django.contrib import admin
-from django.contrib.auth import views as auth_views
-from django.urls import path, include
-from django.conf.urls.static import static
 from django.conf import settings
 from django.conf.urls.i18n import i18n_patterns
-from django.conf.urls import url
+from django.conf.urls.static import static
 from django.templatetags.static import static as get_static_url
-from django.urls import path, reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.urls import include, path, re_path, reverse_lazy
 from django.views.generic.base import RedirectView
-from django.views.i18n import JavaScriptCatalog
-
 
 #: The url patterns of this module (see :doc:`django:topics/http/urls`)
 urlpatterns = [
@@ -42,10 +35,13 @@ urlpatterns = [
     ),
     path("api/", include("lunes_cms.api.urls", namespace="api")),
     path("", include("lunes_cms.help.urls")),
-    url(r"^i18n/", include("django.conf.urls.i18n")),
+    re_path(r"^i18n/", include("django.conf.urls.i18n")),
     path("qr_code/", include("qr_code.urls", namespace="qr_code")),
 ]
 
+urlpatterns += i18n_patterns(
+    path("admin/cmsv2/", include("lunes_cms.cmsv2.urls", namespace="cmsv2"))
+)
 urlpatterns += i18n_patterns(path("", include("lunes_cms.cms.urls")))
 
 if settings.DEBUG:
